@@ -1,6 +1,6 @@
 """nitdms"""
 from nitdms.reader import TdmsFile
-from nitdms.waveformdatatype import WaveformDT
+from waveformDT.waveform import WaveformDT
 from nitdms.version import __version__
 
 __all__ = ["TdmsFile", "WaveformDT"]
