@@ -252,7 +252,8 @@ class TdmsFile(TdmsObject):
                             ch_data_start,
                             STRUCT_FORMAT[TdsDataType(dtype)],
                             TdsDataType(dtype),
-                            None,
+                            # None,
+                            n_objects,
                             count,
                             byte_order,
                             interleaved,
